==> zio-aws-workspaces_2.13-5.17.295.20-sources.jar: zio/aws/workspaces/model/DefaultClientBrandingAttributes.scala <==
package zio.aws.workspaces.model
import zio.aws.workspaces.model.primitives.{
  ClientLoginMessage,
  ClientLocale,
  ClientEmail,
  ClientUrl
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class DefaultClientBrandingAttributes(
    logoUrl: Optional[ClientUrl] = Optional.Absent,
    supportEmail: Optional[ClientEmail] = Optional.Absent,
    supportLink: Optional[ClientUrl] = Optional.Absent,
    forgotPasswordLink: Optional[ClientUrl] = Optional.Absent,
    loginMessage: Optional[Map[ClientLocale, ClientLoginMessage]] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.workspaces.model.DefaultClientBrandingAttributes = {
    import DefaultClientBrandingAttributes.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.workspaces.model.DefaultClientBrandingAttributes
      .builder()
      .optionallyWith(
        logoUrl.map(value => ClientUrl.unwrap(value): java.lang.String)
      )(_.logoUrl)
      .optionallyWith(
        supportEmail.map(value => ClientEmail.unwrap(value): java.lang.String)
      )(_.supportEmail)
      .optionallyWith(
        supportLink.map(value => ClientUrl.unwrap(value): java.lang.String)
      )(_.supportLink)
      .optionallyWith(
        forgotPasswordLink.map(value =>
          ClientUrl.unwrap(value): java.lang.String
        )
      )(_.forgotPasswordLink)
      .optionallyWith(
        loginMessage.map(value =>
          value
            .map({ case (key, value) =>
              (ClientLocale
                .unwrap(key): java.lang.String) -> (ClientLoginMessage
                .unwrap(value): java.lang.String)
            })
            .asJava
        )
      )(_.loginMessage)
      .build()
  }
  def asReadOnly
      : zio.aws.workspaces.model.DefaultClientBrandingAttributes.ReadOnly =
    zio.aws.workspaces.model.DefaultClientBrandingAttributes
      .wrap(buildAwsValue())
}
object DefaultClientBrandingAttributes {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.workspaces.model.DefaultClientBrandingAttributes
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.workspaces.model.DefaultClientBrandingAttributes =
      zio.aws.workspaces.model.DefaultClientBrandingAttributes(
        logoUrl.map(value => value),
        supportEmail.map(value => value),
        supportLink.map(value => value),
        forgotPasswordLink.map(value => value),
        loginMessage.map(value => value)
      )
    def logoUrl: Optional[ClientUrl]
    def supportEmail: Optional[ClientEmail]
    def supportLink: Optional[ClientUrl]
    def forgotPasswordLink: Optional[ClientUrl]
    def loginMessage: Optional[Map[ClientLocale, ClientLoginMessage]]
    def getLogoUrl: ZIO[Any, AwsError, ClientUrl] =
      AwsError.unwrapOptionField("logoUrl", logoUrl)
    def getSupportEmail: ZIO[Any, AwsError, ClientEmail] =
      AwsError.unwrapOptionField("supportEmail", supportEmail)
    def getSupportLink: ZIO[Any, AwsError, ClientUrl] =
      AwsError.unwrapOptionField("supportLink", supportLink)
    def getForgotPasswordLink: ZIO[Any, AwsError, ClientUrl] =
      AwsError.unwrapOptionField("forgotPasswordLink", forgotPasswordLink)
    def getLoginMessage
        : ZIO[Any, AwsError, Map[ClientLocale, ClientLoginMessage]] =
      AwsError.unwrapOptionField("loginMessage", loginMessage)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.workspaces.model.DefaultClientBrandingAttributes
  ) extends zio.aws.workspaces.model.DefaultClientBrandingAttributes.ReadOnly {
    override val logoUrl: Optional[ClientUrl] = zio.aws.core.internal
      .optionalFromNullable(impl.logoUrl())
      .map(value => zio.aws.workspaces.model.primitives.ClientUrl(value))
    override val supportEmail: Optional[ClientEmail] = zio.aws.core.internal
      .optionalFromNullable(impl.supportEmail())
      .map(value => zio.aws.workspaces.model.primitives.ClientEmail(value))
    override val supportLink: Optional[ClientUrl] = zio.aws.core.internal
      .optionalFromNullable(impl.supportLink())
      .map(value => zio.aws.workspaces.model.primitives.ClientUrl(value))
    override val forgotPasswordLink: Optional[ClientUrl] = zio.aws.core.internal
      .optionalFromNullable(impl.forgotPasswordLink())
      .map(value => zio.aws.workspaces.model.primitives.ClientUrl(value))
    override val loginMessage: Optional[Map[ClientLocale, ClientLoginMessage]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.loginMessage())
        .map(value =>
          value.asScala
            .map({ case (key, value) =>
              zio.aws.workspaces.model.primitives.ClientLocale(
                key
              ) -> zio.aws.workspaces.model.primitives.ClientLoginMessage(value)
            })
            .toMap
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.workspaces.model.DefaultClientBrandingAttributes
  ): zio.aws.workspaces.model.DefaultClientBrandingAttributes.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-workspaces_3-5.17.171.1-sources.jar: zio/aws/workspaces/model/DefaultClientBrandingAttributes.scala <==
package zio.aws.workspaces.model
import zio.aws.workspaces.model.primitives.{
  ClientLoginMessage,
  ClientLocale,
  ClientEmail,
  ClientUrl
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class DefaultClientBrandingAttributes(
    logoUrl: Optional[ClientUrl] = Optional.Absent,
    supportEmail: Optional[ClientEmail] = Optional.Absent,
    supportLink: Optional[ClientUrl] = Optional.Absent,
    forgotPasswordLink: Optional[ClientUrl] = Optional.Absent,
    loginMessage: Optional[Map[ClientLocale, ClientLoginMessage]] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.workspaces.model.DefaultClientBrandingAttributes = {
    import DefaultClientBrandingAttributes.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.workspaces.model.DefaultClientBrandingAttributes
      .builder()
      .optionallyWith(
        logoUrl.map(value => ClientUrl.unwrap(value): java.lang.String)
      )(_.logoUrl)
      .optionallyWith(
        supportEmail.map(value => ClientEmail.unwrap(value): java.lang.String)
      )(_.supportEmail)
      .optionallyWith(
        supportLink.map(value => ClientUrl.unwrap(value): java.lang.String)
      )(_.supportLink)
      .optionallyWith(
        forgotPasswordLink.map(value =>
          ClientUrl.unwrap(value): java.lang.String
        )
      )(_.forgotPasswordLink)
      .optionallyWith(
        loginMessage.map(value =>
          value
            .map({ case (key, value) =>
              (ClientLocale
                .unwrap(key): java.lang.String) -> (ClientLoginMessage
                .unwrap(value): java.lang.String)
            })
            .asJava
        )
      )(_.loginMessage)
      .build()
  }
  def asReadOnly
      : zio.aws.workspaces.model.DefaultClientBrandingAttributes.ReadOnly =
    zio.aws.workspaces.model.DefaultClientBrandingAttributes
      .wrap(buildAwsValue())
}
object DefaultClientBrandingAttributes {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.workspaces.model.DefaultClientBrandingAttributes
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.workspaces.model.DefaultClientBrandingAttributes =
      zio.aws.workspaces.model.DefaultClientBrandingAttributes(
        logoUrl.map(value => value),
        supportEmail.map(value => value),
        supportLink.map(value => value),
        forgotPasswordLink.map(value => value),
        loginMessage.map(value => value)
      )
    def logoUrl: Optional[ClientUrl]
    def supportEmail: Optional[ClientEmail]
    def supportLink: Optional[ClientUrl]
    def forgotPasswordLink: Optional[ClientUrl]
    def loginMessage: Optional[Map[ClientLocale, ClientLoginMessage]]
    def getLogoUrl: ZIO[Any, AwsError, ClientUrl] =
      AwsError.unwrapOptionField("logoUrl", logoUrl)
    def getSupportEmail: ZIO[Any, AwsError, ClientEmail] =
      AwsError.unwrapOptionField("supportEmail", supportEmail)
    def getSupportLink: ZIO[Any, AwsError, ClientUrl] =
      AwsError.unwrapOptionField("supportLink", supportLink)
    def getForgotPasswordLink: ZIO[Any, AwsError, ClientUrl] =
      AwsError.unwrapOptionField("forgotPasswordLink", forgotPasswordLink)
    def getLoginMessage
        : ZIO[Any, AwsError, Map[ClientLocale, ClientLoginMessage]] =
      AwsError.unwrapOptionField("loginMessage", loginMessage)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.workspaces.model.DefaultClientBrandingAttributes
  ) extends zio.aws.workspaces.model.DefaultClientBrandingAttributes.ReadOnly {
    override val logoUrl: Optional[ClientUrl] = zio.aws.core.internal
      .optionalFromNullable(impl.logoUrl())
      .map(value => zio.aws.workspaces.model.primitives.ClientUrl(value))
    override val supportEmail: Optional[ClientEmail] = zio.aws.core.internal
      .optionalFromNullable(impl.supportEmail())
      .map(value => zio.aws.workspaces.model.primitives.ClientEmail(value))
    override val supportLink: Optional[ClientUrl] = zio.aws.core.internal
      .optionalFromNullable(impl.supportLink())
      .map(value => zio.aws.workspaces.model.primitives.ClientUrl(value))
    override val forgotPasswordLink: Optional[ClientUrl] = zio.aws.core.internal
      .optionalFromNullable(impl.forgotPasswordLink())
      .map(value => zio.aws.workspaces.model.primitives.ClientUrl(value))
    override val loginMessage: Optional[Map[ClientLocale, ClientLoginMessage]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.loginMessage())
        .map(value =>
          value.asScala
            .map({ case (key, value) =>
              zio.aws.workspaces.model.primitives.ClientLocale(
                key
              ) -> zio.aws.workspaces.model.primitives.ClientLoginMessage(value)
            })
            .toMap
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.workspaces.model.DefaultClientBrandingAttributes
  ): zio.aws.workspaces.model.DefaultClientBrandingAttributes.ReadOnly =
    new Wrapper(impl)
}
